@@ -19,7 +19,7 @@ from pyro.util import ignore_jit_warnings
 
 def fit_mobster(data, K, tail=1, purity=0.96,alpha_prior_concentration = 5, alpha_prior_rate = 10, number_of_trials_clonal_mean=500.,number_of_trials_k=300.,
          prior_lims_clonal=[0.1, 100000.], prior_lims_k=[0.1, 100000.], stopping = ELBO_stopping_criteria, lr = 0.05,
-                max_it = 5000, e = 0.001, compile = False, CUDA = False, seed = 3):
+                max_it = 5000, e = 0.001, compile = False, CUDA = False, seed = 3, lrd_gamma = 0.1):
 
 
     pyro.set_rng_seed(seed)
@@ -35,9 +35,11 @@ def fit_mobster(data, K, tail=1, purity=0.96,alpha_prior_concentration = 5, alph
     model = mobster.model
     guide = mobster.guide
 
+    lrd = lrd_gamma ** (1/max_it)
+
     svi = pyro.infer.SVI(model=model,
                      guide=guide,
-                     optim=pyro.optim.ClippedAdam({"lr": lr}),
+                     optim=pyro.optim.ClippedAdam({"lr": lr, "lrd" : lrd}),
                      loss= loss())
 
     print('Running MOBSTER on {} karyotypes with {} subclones.'.format(len(data), K), flush=True)
