@@ -107,8 +107,8 @@ def format_parameters_for_export_aux(data, params,k, i, theo_clones, counts_clon
     if tail == 1:
         res["tail_shape"] = params['tail_mean'].detach().numpy()
         res["tail_scale"] = np.min(data[k].detach().numpy())
-        res["tail_shape_sd"] = params['tail_sd'].detach().numpy()
-        res["tail_noise"] =  params['alpha_noise'][i].detach().numpy()
+        res["tail_shape_sd"] = 1/params['tail_sd'].detach().numpy()
+        res["tail_noise"] =  1/params['alpha_noise'][i].detach().numpy()
 
     return res
 
